Package io.microsphere.spring.boot
Enum Class SpringBootVersion
- All Implemented Interfaces:
Serializable,Comparable<SpringBootVersion>,Constable
The enumeration for the released Spring Boot versions since 3.0
- Since:
- 1.0.0
- Author:
- Mercy
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescription -
Method Summary
Modifier and TypeMethodDescriptionbooleaneq(SpringBootVersion that) booleanequals(SpringBootVersion that) booleange(SpringBootVersion that) intgetMajor()intgetMinor()intgetPatch()io.microsphere.util.Versionbooleangt(SpringBootVersion that) booleanbooleanbooleanbooleanisLessThan(SpringBootVersion that) booleanle(SpringBootVersion that) booleanlt(SpringBootVersion that) static SpringBootVersionReturns the enum constant of this class with the specified name.static SpringBootVersion[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
SPRING_BOOT_3_0
-
SPRING_BOOT_3_0_0
-
SPRING_BOOT_3_0_1
-
SPRING_BOOT_3_0_2
-
SPRING_BOOT_3_0_3
-
SPRING_BOOT_3_0_4
-
SPRING_BOOT_3_0_5
-
SPRING_BOOT_3_0_6
-
SPRING_BOOT_3_0_7
-
SPRING_BOOT_3_0_8
-
SPRING_BOOT_3_0_9
-
SPRING_BOOT_3_0_10
-
SPRING_BOOT_3_0_11
-
SPRING_BOOT_3_0_12
-
SPRING_BOOT_3_0_13
-
SPRING_BOOT_3_1
-
SPRING_BOOT_3_1_0
-
SPRING_BOOT_3_1_1
-
SPRING_BOOT_3_1_2
-
SPRING_BOOT_3_1_3
-
SPRING_BOOT_3_1_4
-
SPRING_BOOT_3_1_5
-
SPRING_BOOT_3_1_6
-
SPRING_BOOT_3_1_7
-
SPRING_BOOT_3_1_8
-
SPRING_BOOT_3_1_9
-
SPRING_BOOT_3_1_10
-
SPRING_BOOT_3_1_11
-
SPRING_BOOT_3_1_12
-
SPRING_BOOT_3_2
-
SPRING_BOOT_3_2_0
-
SPRING_BOOT_3_2_1
-
SPRING_BOOT_3_2_2
-
SPRING_BOOT_3_2_3
-
SPRING_BOOT_3_2_4
-
SPRING_BOOT_3_2_5
-
SPRING_BOOT_3_2_6
-
SPRING_BOOT_3_2_7
-
SPRING_BOOT_3_2_8
-
SPRING_BOOT_3_2_9
-
SPRING_BOOT_3_2_10
-
SPRING_BOOT_3_2_11
-
SPRING_BOOT_3_2_12
-
SPRING_BOOT_3_3
-
SPRING_BOOT_3_3_0
-
SPRING_BOOT_3_3_1
-
SPRING_BOOT_3_3_2
-
SPRING_BOOT_3_3_3
-
SPRING_BOOT_3_3_4
-
SPRING_BOOT_3_3_5
-
SPRING_BOOT_3_3_6
-
SPRING_BOOT_3_3_7
-
SPRING_BOOT_3_3_8
-
SPRING_BOOT_3_3_9
-
SPRING_BOOT_3_3_10
-
SPRING_BOOT_3_3_11
-
SPRING_BOOT_3_3_12
-
SPRING_BOOT_3_3_13
-
SPRING_BOOT_3_4
-
SPRING_BOOT_3_4_0
-
SPRING_BOOT_3_4_1
-
SPRING_BOOT_3_4_2
-
SPRING_BOOT_3_4_3
-
SPRING_BOOT_3_4_4
-
SPRING_BOOT_3_4_5
-
SPRING_BOOT_3_4_6
-
SPRING_BOOT_3_4_7
-
SPRING_BOOT_3_4_8
-
SPRING_BOOT_3_4_9
-
SPRING_BOOT_3_4_10
-
SPRING_BOOT_3_4_11
-
SPRING_BOOT_3_4_12
-
SPRING_BOOT_3_4_13
-
SPRING_BOOT_3_5
-
SPRING_BOOT_3_5_0
-
SPRING_BOOT_3_5_1
-
SPRING_BOOT_3_5_2
-
SPRING_BOOT_3_5_3
-
SPRING_BOOT_3_5_4
-
SPRING_BOOT_3_5_5
-
SPRING_BOOT_3_5_6
-
SPRING_BOOT_3_5_7
-
SPRING_BOOT_3_5_8
-
SPRING_BOOT_3_5_9
-
SPRING_BOOT_3_5_10
-
SPRING_BOOT_3_5_11
-
SPRING_BOOT_3_5_12
-
SPRING_BOOT_3_5_13
-
SPRING_BOOT_3_5_14
-
SPRING_BOOT_4_0
-
SPRING_BOOT_4_0_0
-
SPRING_BOOT_4_0_1
-
SPRING_BOOT_4_0_2
-
SPRING_BOOT_4_0_3
-
SPRING_BOOT_4_0_4
-
SPRING_BOOT_4_0_5
-
SPRING_BOOT_4_0_6
-
CURRENT
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getVersion
public io.microsphere.util.Version getVersion() -
getMajor
public int getMajor() -
getMinor
public int getMinor() -
getPatch
public int getPatch() -
gt
-
isGreaterThan
-
ge
-
isGreaterOrEqual
-
lt
-
isLessThan
-
le
-
isLessOrEqual
-
eq
-
equals
-