Uses of Enum Class
io.microsphere.spring.boot.SpringBootVersion
Packages that use SpringBootVersion
-
Uses of SpringBootVersion in io.microsphere.spring.boot
Methods in io.microsphere.spring.boot that return SpringBootVersionModifier and TypeMethodDescriptionstatic SpringBootVersionReturns the enum constant of this class with the specified name.static SpringBootVersion[]SpringBootVersion.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in io.microsphere.spring.boot with parameters of type SpringBootVersionModifier and TypeMethodDescriptionbooleanSpringBootVersion.eq(SpringBootVersion that) booleanSpringBootVersion.equals(SpringBootVersion that) booleanSpringBootVersion.ge(SpringBootVersion that) booleanSpringBootVersion.gt(SpringBootVersion that) booleanSpringBootVersion.isGreaterOrEqual(SpringBootVersion that) booleanSpringBootVersion.isGreaterThan(SpringBootVersion that) booleanSpringBootVersion.isLessOrEqual(SpringBootVersion that) booleanSpringBootVersion.isLessThan(SpringBootVersion that) booleanSpringBootVersion.le(SpringBootVersion that) booleanSpringBootVersion.lt(SpringBootVersion that)