Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- addDefaultPropertiesResource(String) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Add "defaultProperties" resource path
- addDefaultPropertiesResources(String...) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Add one or more "defaultProperties" resource paths
- addExcludedAutoConfigurationClass(Environment, String) - Static method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Add a class name to exclude Spring Boot Auto-Configuration
- addExcludedAutoConfigurationClasses(Environment, Iterable<String>) - Static method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Add the class names to exclude Spring Boot Auto-Configuration
- addExcludedAutoConfigurationClasses(Environment, String, String...) - Static method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Add one or more class names to exclude Spring Boot Auto-Configuration
- ADDITIONAL_METADATA_PATH - Static variable in class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
- afterSingletonsInstantiated() - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Called after all singleton beans have been instantiated, marking that initial binding is complete.
- analyze(Throwable, ArtifactsCollisionException) - Method in class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionFailureAnalyzer
-
Analyzes the given
ArtifactsCollisionExceptionand produces aFailureAnalysiscontaining the collision message and a recommended action to resolve it. - apply(BindHandler) - Method in class io.microsphere.spring.boot.context.properties.ListenableConfigurationPropertiesBindHandlerAdvisor
-
Applies this advisor by wrapping the given
BindHandlerwith aListenableBindHandlerAdapterthat delegates to all discoveredBindListenerbeans. - args - Variable in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.
- ArtifactsCollisionDiagnosisListener - Class in io.microsphere.spring.boot.diagnostics
-
ApplicationListenerto detect and diagnose artifacts collision in the application classpath. - ArtifactsCollisionDiagnosisListener() - Constructor for class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionDiagnosisListener
- ArtifactsCollisionException - Exception in io.microsphere.spring.boot.diagnostics
-
Artifacts Collision
RuntimeException - ArtifactsCollisionException(String, Set<String>) - Constructor for exception io.microsphere.spring.boot.diagnostics.ArtifactsCollisionException
-
Construct a new
ArtifactsCollisionExceptionwith the given message and set of colliding artifacts. - ArtifactsCollisionFailureAnalyzer - Class in io.microsphere.spring.boot.diagnostics
-
Artifacts Collision
FailureAnalyzerClass - ArtifactsCollisionFailureAnalyzer() - Constructor for class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionFailureAnalyzer
- ATTACHED_PROPERTY_SOURCE_NAME - Static variable in interface io.microsphere.spring.boot.constants.SpringBootPropertyConstants
-
The name of the
PropertySourceadaptersince Spring Boot 2 - AUTO_CONFIGURE_EXCLUDE_PROPERTY_NAME - Static variable in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
- AutoRegistrationBeanInitializer - Class in io.microsphere.spring.boot.context.config
-
ApplicationContextInitializerclass forAutoRegistrationBean - AutoRegistrationBeanInitializer() - Constructor for class io.microsphere.spring.boot.context.config.AutoRegistrationBeanInitializer
B
- BANNED_ARTIFACTS_ENABLED_PROPERTY_NAME - Static variable in class io.microsphere.spring.boot.classloading.BannedArtifactClassLoadingListener
- BannedArtifactClassLoadingListener - Class in io.microsphere.spring.boot.classloading
-
ApplicationStartingEventApplicationListenerthat bans loading of artifact collision classes. - BannedArtifactClassLoadingListener(SpringApplication, String...) - Constructor for class io.microsphere.spring.boot.classloading.BannedArtifactClassLoadingListener
-
Construct a new
BannedArtifactClassLoadingListenerwith the given application and arguments. - BASE_PACKAGES_PROPERTY_NAME - Static variable in class io.microsphere.spring.boot.report.ConditionsReportMessageBuilder
-
The base packages for Spring Boot Conditions Report : "microsphere.spring.boot.conditions.report.base-packages"
- BEAN_NAME - Static variable in class io.microsphere.spring.boot.env.config.OriginTrackedConfigurationPropertyInitializer
- bind(Map<?, ?>, String, Class<T>, BindListener...) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Bind configuration properties to a target type using the provided properties map and property name prefix.
- bind(Map<String, Object>, boolean, boolean, Object) - Method in class io.microsphere.spring.boot.context.config.BindableConfigurationBeanBinder
-
Binds the given configuration properties to the specified bean using Spring Boot's
Binder. - bind(Binder, String, Class<T>, BindListener...) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Bind configuration properties to a target type using the provided
Binderand property name prefix. - bind(Environment, String, Class<T>, BindListener...) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Bind configuration properties to a target type using the provided environment and property name prefix.
- BindableConfigurationBeanBinder - Class in io.microsphere.spring.boot.context.config
-
A
ConfigurationBeanBinderimplementation based on Spring Boot 2'sBinder, which binds configuration properties to a given bean usingBindable. - BindableConfigurationBeanBinder() - Constructor for class io.microsphere.spring.boot.context.config.BindableConfigurationBeanBinder
- BindHandlerUtils - Class in io.microsphere.spring.boot.context.properties.bind.util
-
The utilities class of
BindHandler - BindListener - Interface in io.microsphere.spring.boot.context.properties.bind
-
Bind Listener
- BindUtils - Class in io.microsphere.spring.boot.context.properties.bind.util
-
The utilities class for binding
C
- ConditionalOnPropertyPrefix - Annotation Interface in io.microsphere.spring.boot.condition
-
Conditionalthat checks if the prefix of properties are found in environment.. - ConditionEvaluationReportInitializer - Class in io.microsphere.spring.boot.report
-
ConditionEvaluationReportinitializer - ConditionEvaluationReportInitializer() - Constructor for class io.microsphere.spring.boot.report.ConditionEvaluationReportInitializer
- ConditionEvaluationReportListener - Class in io.microsphere.spring.boot.report
-
Spring Boot Conditions Evaluation report listener
- ConditionEvaluationReportListener() - Constructor for class io.microsphere.spring.boot.report.ConditionEvaluationReportListener
- ConditionEvaluationSpringBootExceptionReporter - Class in io.microsphere.spring.boot.report
-
Spring Boot Conditions
SpringBootExceptionReporter - ConditionEvaluationSpringBootExceptionReporter(ConfigurableApplicationContext) - Constructor for class io.microsphere.spring.boot.report.ConditionEvaluationSpringBootExceptionReporter
-
Constructs a new
ConditionEvaluationSpringBootExceptionReporterwith the given application context. - ConditionsReportMessageBuilder - Class in io.microsphere.spring.boot.report
-
Spring Boot Conditions Report builder
- ConditionsReportMessageBuilder(ConfigurableApplicationContext) - Constructor for class io.microsphere.spring.boot.report.ConditionsReportMessageBuilder
-
Constructs a new
ConditionsReportMessageBuilderwith the given application context. - ConfigurableAutoConfigurationImportFilter - Class in io.microsphere.spring.boot.autoconfigure
-
Configurable
AutoConfigurationImportFilterfor excluding specific Spring Boot auto-configuration classes. - ConfigurableAutoConfigurationImportFilter() - Constructor for class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
- CONFIGURATION_PROPERTIES_CLASS - Static variable in class io.microsphere.spring.boot.context.properties.util.ConfigurationPropertiesUtils
-
The
ClassofConfigurationProperties - ConfigurationMetadataReader - Class in io.microsphere.spring.boot.context.properties.metadata
-
ConfigurationMetadataReader - ConfigurationMetadataReader() - Constructor for class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
- ConfigurationMetadataRepository - Class in io.microsphere.spring.boot.env.config.metadata
-
The Repository for
ConfigurationMetadata - ConfigurationMetadataRepository(ConfigurationMetadataReader) - Constructor for class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Constructs a new
ConfigurationMetadataRepositorybacked by the givenConfigurationMetadataReader. - ConfigurationPropertiesBeanInfo - Class in io.microsphere.spring.boot.context.properties
-
The information class for introspecting the bean annotated
@ConfigurationProperties. - ConfigurationPropertiesBeanInfo(Class<?>) - Constructor for class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Constructs a
ConfigurationPropertiesBeanInfoby introspecting the given bean class for its@ConfigurationPropertiesannotation. - ConfigurationPropertiesBeanInfo(Class<?>, ConfigurationProperties) - Constructor for class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Constructs a
ConfigurationPropertiesBeanInfowith the given bean class and annotation, deriving the prefix from the annotation'sprefixorvalueattribute. - ConfigurationPropertiesBeanInfo(Class<?>, ConfigurationProperties, String) - Constructor for class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
- ConfigurationPropertiesBeanPropertyChangedEvent<T> - Class in io.microsphere.spring.boot.context.properties.bind
-
Event raised when the property of bean annotated
@ConfigurationPropertieswas changed. - ConfigurationPropertiesBeanPropertyChangedEvent(Object, String, Object, Object, ConfigurationProperty) - Constructor for class io.microsphere.spring.boot.context.properties.bind.ConfigurationPropertiesBeanPropertyChangedEvent
-
Constructs a new event indicating that a configuration property bound to a
@ConfigurationPropertiesbean has changed. - ConfigurationPropertiesUtils - Class in io.microsphere.spring.boot.context.properties.util
-
The utilities class of
ConfigurationProperties - ConfigurationPropertyUtils - Class in io.microsphere.spring.boot.context.properties.source.util
-
The utilities class of
ConfigurationProperty - contextLoaded(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the
ConfigurableApplicationContexthas been loaded with bean definitions. - contextLoaded(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the
ConfigurableApplicationContexthas been loaded with bean definitions but not yet refreshed. - contextPrepared(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the
ConfigurableApplicationContexthas been prepared. - contextPrepared(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the
ConfigurableApplicationContexthas been prepared but before bean definitions are loaded. - createBindHandler(boolean, boolean) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindHandlerUtils
-
Create a
BindHandlerinstance based on the given flags. - CURRENT - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
D
- DEFAULT_MICROSPHERE_SPRING_BOOT_LOGGING_LEVEL - Static variable in interface io.microsphere.spring.boot.constants.PropertyConstants
-
The default value of Microsphere Spring Boot logging level : "TRACE"
- DEFAULT_ORDER - Static variable in class io.microsphere.spring.boot.env.DefaultPropertiesApplicationListener
- DEFAULT_PROPERTIES_RESOURCES_PATTERN - Static variable in class io.microsphere.spring.boot.env.SpringApplicationDefaultPropertiesPostProcessor
-
The resource pattern to load the properties resources.
- DefaultPropertiesApplicationListener - Class in io.microsphere.spring.boot.env
-
ApplicationListenerimplementation that handlesApplicationEnvironmentPreparedEventto process and merge default properties from various sources into Spring Boot application environment. - DefaultPropertiesApplicationListener() - Constructor for class io.microsphere.spring.boot.env.DefaultPropertiesApplicationListener
-
Constructs a new
DefaultPropertiesApplicationListenerwith thedefault order. - DefaultPropertiesPostProcessor - Interface in io.microsphere.spring.boot.env
-
"defaultProperties"Post Processor. - diagnose(ClassLoader) - Method in class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionDiagnosisListener
-
Diagnose artifact collisions by scanning the given
ClassLoaderfor duplicate artifacts.
E
- ENABLED_PROPERTY_NAME - Static variable in class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionDiagnosisListener
-
Whether to enable the Artifacts Collision diagnosis : "microsphere.spring.boot.artifacts-collision.enabled"
- environmentPrepared(ConfigurableEnvironment) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the
ConfigurableEnvironmenthas been prepared. - environmentPrepared(ConfigurableEnvironment) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the
ConfigurableEnvironmenthas been prepared. - eq(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- equals(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- equals(Object) - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Compares this instance with the specified object for equality based on bean class and prefix.
- EventPublishingConfigurationPropertiesBeanPropertyChangedListener - Class in io.microsphere.spring.boot.context.properties.bind
-
A
BindListenerimplementation of@ConfigurationPropertiesBean to publish theConfigurationPropertiesBeanPropertyChangedEvent - EventPublishingConfigurationPropertiesBeanPropertyChangedListener() - Constructor for class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
F
- failed(ConfigurableApplicationContext, Throwable) - Method in class io.microsphere.spring.boot.listener.FailureReportSpringApplicationRunListener
-
Deprecated.Handles application startup failure by printing the exception details to
System.err. - failed(ConfigurableApplicationContext, Throwable) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the application has failed to start with the given exception.
- failed(ConfigurableApplicationContext, Throwable) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the application has failed to start.
- FailureReportSpringApplicationRunListener - Class in io.microsphere.spring.boot.listener
-
Deprecated, for removal: This API element is subject to removal in a future version.
- FailureReportSpringApplicationRunListener(SpringApplication, String[]) - Constructor for class io.microsphere.spring.boot.listener.FailureReportSpringApplicationRunListener
-
Deprecated.Construct a new
FailureReportSpringApplicationRunListener. - findConfigurationProperties(Bindable) - Static method in class io.microsphere.spring.boot.context.properties.util.ConfigurationPropertiesUtils
-
Find an annotation of
ConfigurationPropertiesfrom the specifiedBindable.
G
- ge(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- getAnnotation() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns the
ConfigurationPropertiesannotation of the bean. - getArgs() - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Return the command line arguments passed to the application.
- getArtifacts() - Method in exception io.microsphere.spring.boot.diagnostics.ArtifactsCollisionException
-
Return the set of colliding artifact identifiers.
- getBeanClass() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns the bean class associated with this info.
- getConfigurationMetadataReader() - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the underlying
ConfigurationMetadataReaderused to read configuration metadata. - getConfigurationProperty() - Method in class io.microsphere.spring.boot.context.properties.bind.ConfigurationPropertiesBeanPropertyChangedEvent
-
Returns the
ConfigurationPropertyassociated with the property change. - getDefaultPropertiesResources() - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
- getExcludedAutoConfigurationClasses(Environment) - Static method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Retrieves the complete set of excluded auto-configuration class names from the given
Environment, combining property source values andBinderresults. - getFileExtensions() - Method in class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Returns all file extensions supported by the underlying
PropertySourceLoaderinstances. - getGroup(String) - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the configuration metadata group item for the given name.
- getGroups() - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns all configuration metadata group items.
- getHints(String) - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the list of
ItemHintinstances associated with the given property name. - getLoggingLevel(ConfigurableApplicationContext) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Get logging level with upper case from the Spring
PropertySources - getLoggingLevel(PropertyResolver) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Get logging level(Upper case) from the Spring
PropertySources - getMajor() - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- getMinor() - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- getOrder() - Method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Returns the order of this filter.
- getOrder() - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Returns the order value of this listener, as set by
OnceApplicationPreparedEventListener.setOrder(int). - getOrder() - Method in class io.microsphere.spring.boot.env.DefaultPropertiesApplicationListener
-
Returns the order value of this listener.
- getOrder() - Method in interface io.microsphere.spring.boot.env.DefaultPropertiesPostProcessor
-
Get the order of
DefaultPropertiesPostProcessor - getOrder() - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Return the order of this listener.
- getPatch() - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- getPrefix() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns the property name prefix for this configuration properties bean.
- getPrefix(ConfigurationPropertyName, BindContext) - Static method in class io.microsphere.spring.boot.context.properties.source.util.ConfigurationPropertyUtils
-
Get the prefix of the specified
ConfigurationPropertyName - getProperties() - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns all configuration metadata property items.
- getProperty(String) - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the configuration metadata property item for the given name.
- getPropertyDescriptor(String) - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns the
PropertyDescriptorfor the specified property name. - getPropertyDescriptors() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns all
PropertyDescriptors of the bean class. - getPropertyGroups() - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the set of all configuration property group names.
- getPropertyNames() - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Returns the set of all configuration property names.
- getResourceLoader(SpringApplication) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Get the
ResourceLoaderfrom the givenSpringApplication. - getResourcePatternResolver() - Method in class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
-
Returns the
ResourcePatternResolverused to locate configuration metadata resources. - getSpringApplication() - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Return the underlying
SpringApplicationinstance. - getVersion() - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- gt(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
H
- hashCode() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns a hash code based on the bean class and prefix.
I
- initialize(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.config.AutoRegistrationBeanInitializer
- initialize(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.env.config.OriginTrackedConfigurationPropertyInitializer
-
Initializes the application context by storing references and registering this instance as a bean in the bean factory.
- initialize(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.report.ConditionEvaluationReportInitializer
-
Initializes the
ConditionEvaluationReportby registering aBeanFactoryPostProcessorthat builds the report for the application context's bean factory. - initializeResources(Set<String>) - Method in interface io.microsphere.spring.boot.env.DefaultPropertiesPostProcessor
-
Initialize
"defaultProperties" resources - initializeResources(Set<String>) - Method in class io.microsphere.spring.boot.env.SpringApplicationDefaultPropertiesPostProcessor
-
Initializes the default properties resources by adding the
SpringApplicationDefaultPropertiesPostProcessor.DEFAULT_PROPERTIES_RESOURCES_PATTERNwildcard pattern for loading all property source resources from/META-INF/config/default/. - io.microsphere.spring.boot - package io.microsphere.spring.boot
- io.microsphere.spring.boot.autoconfigure - package io.microsphere.spring.boot.autoconfigure
- io.microsphere.spring.boot.classloading - package io.microsphere.spring.boot.classloading
- io.microsphere.spring.boot.condition - package io.microsphere.spring.boot.condition
- io.microsphere.spring.boot.constants - package io.microsphere.spring.boot.constants
- io.microsphere.spring.boot.context - package io.microsphere.spring.boot.context
- io.microsphere.spring.boot.context.config - package io.microsphere.spring.boot.context.config
- io.microsphere.spring.boot.context.properties - package io.microsphere.spring.boot.context.properties
- io.microsphere.spring.boot.context.properties.bind - package io.microsphere.spring.boot.context.properties.bind
- io.microsphere.spring.boot.context.properties.bind.util - package io.microsphere.spring.boot.context.properties.bind.util
- io.microsphere.spring.boot.context.properties.metadata - package io.microsphere.spring.boot.context.properties.metadata
- io.microsphere.spring.boot.context.properties.source.util - package io.microsphere.spring.boot.context.properties.source.util
- io.microsphere.spring.boot.context.properties.util - package io.microsphere.spring.boot.context.properties.util
- io.microsphere.spring.boot.diagnostics - package io.microsphere.spring.boot.diagnostics
- io.microsphere.spring.boot.env - package io.microsphere.spring.boot.env
- io.microsphere.spring.boot.env.config - package io.microsphere.spring.boot.env.config
- io.microsphere.spring.boot.env.config.metadata - package io.microsphere.spring.boot.env.config.metadata
- io.microsphere.spring.boot.listener - package io.microsphere.spring.boot.listener
- io.microsphere.spring.boot.report - package io.microsphere.spring.boot.report
- io.microsphere.spring.boot.util - package io.microsphere.spring.boot.util
- isBound() - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Returns whether the initial binding of all singleton beans has been completed.
- isBoundProperty(BindContext) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Checks if the given
BindContextrepresents a bound property. - isConfigurationPropertiesBean(Bindable<?>, BindContext) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Checks if the given
Bindabletarget andBindContextrepresent a bean annotated withConfigurationPropertiesat the root binding level. - isConfigurationPropertiesBean(BindContext) - Static method in class io.microsphere.spring.boot.context.properties.bind.util.BindUtils
-
Checks if the given
BindContextrepresents a bean annotated withConfigurationPropertiesat the root binding level (depth = 0). - isGreaterOrEqual(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- isGreaterThan(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- isIgnored(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.LoggingOnceApplicationPreparedEventListener
-
Determines whether this listener should be ignored based on the configured logging level.
- isIgnored(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Determines whether the given application context should be ignored and not processed by this listener.
- isIgnored(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.OnceMainApplicationPreparedEventListener
-
Determines whether the given application context should be ignored by delegating to
OnceMainApplicationPreparedEventListener.isIgnored(ConfigurableApplicationContext). - isIgnored(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.OnceMainApplicationPreparedEventListener
-
Determines whether the given application context should be ignored.
- isLessOrEqual(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- isLessThan(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- isProcessed(String) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Checks whether the application context with the given id has already been processed by this listener.
L
- le(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
- ListenableBindHandlerAdapter - Class in io.microsphere.spring.boot.context.properties.bind
-
Listable
BindHandlerAdapter - ListenableBindHandlerAdapter(Iterable<BindListener>) - Constructor for class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Constructs a
ListenableBindHandlerAdapterwith the default parentBindHandler. - ListenableBindHandlerAdapter(BindHandler, Iterable<BindListener>) - Constructor for class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Constructs a
ListenableBindHandlerAdapterwith the specified parentBindHandler. - ListenableConfigurationPropertiesBindHandlerAdvisor - Class in io.microsphere.spring.boot.context.properties
-
ConfigurationPropertiesBindHandlerAdvisorsupports the chaining of theBindListeners' beans - ListenableConfigurationPropertiesBindHandlerAdvisor() - Constructor for class io.microsphere.spring.boot.context.properties.ListenableConfigurationPropertiesBindHandlerAdvisor
- load(String, Resource) - Method in class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Loads property sources from the given resource by delegating to each registered
PropertySourceLoaderthat supports the resource's file extension. - loadAsOriginTracked(String, String) - Method in class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Load the
PropertySourceas an instance ofPropertySourcewithOriginLookup - log(SpringApplication, String[], String, Object...) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Log
SpringApplication - log(SpringApplication, String[], ConfigurableApplicationContext, String, Object...) - Static method in class io.microsphere.spring.boot.util.SpringApplicationUtils
-
Log
SpringApplication - logger - Variable in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
- LoggingOnceApplicationPreparedEventListener - Class in io.microsphere.spring.boot.context
-
OnceApplicationPreparedEventListenerclass for logging with specified level. - LoggingOnceApplicationPreparedEventListener() - Constructor for class io.microsphere.spring.boot.context.LoggingOnceApplicationPreparedEventListener
-
Constructs a new
LoggingOnceApplicationPreparedEventListenerwith the lowest precedence order. - LoggingOnceMainApplicationPreparedEventListener - Class in io.microsphere.spring.boot.context
-
OnceMainApplicationPreparedEventListenerfor Logging with specified level - LoggingOnceMainApplicationPreparedEventListener() - Constructor for class io.microsphere.spring.boot.context.LoggingOnceMainApplicationPreparedEventListener
-
Constructs a new
LoggingOnceMainApplicationPreparedEventListenerwith the lowest precedence order. - LoggingSpringApplicationRunListener - Class in io.microsphere.spring.boot.listener
-
Deprecated, for removal: This API element is subject to removal in a future version.
- LoggingSpringApplicationRunListener(SpringApplication, String[]) - Constructor for class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Construct a new
LoggingSpringApplicationRunListener. - lt(SpringBootVersion) - Method in enum class io.microsphere.spring.boot.SpringBootVersion
M
- markProcessed(String) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Marks the application context with the given id as processed so that subsequent events for the same context are ignored.
- match(String[], AutoConfigurationMetadata) - Method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Filters the given auto-configuration classes, returning an array of booleans indicating which classes should be imported (
true) and which are excluded (false). - METADATA_PATH - Static variable in class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
- MICROSPHERE_SPRING_BOOT_LOGGING_LEVEL_PROPERTY_NAME - Static variable in interface io.microsphere.spring.boot.constants.PropertyConstants
-
The property name of Microsphere Spring Boot logging level
- MICROSPHERE_SPRING_BOOT_PROPERTY_NAME_PREFIX - Static variable in interface io.microsphere.spring.boot.constants.PropertyConstants
-
The property name prefix of Microsphere Spring Boot : "microsphere.spring.boot."
O
- onApplicationEvent(ApplicationContextInitializedEvent) - Method in class io.microsphere.spring.boot.diagnostics.ArtifactsCollisionDiagnosisListener
-
Handles the
ApplicationContextInitializedEventby diagnosing artifact collisions if the feature is enabled via theArtifactsCollisionDiagnosisListener.ENABLED_PROPERTY_NAMEproperty. - onApplicationEvent(ApplicationEnvironmentPreparedEvent) - Method in class io.microsphere.spring.boot.env.DefaultPropertiesApplicationListener
-
Handles the
ApplicationEnvironmentPreparedEventby processing and merging default properties from various sources into the Spring Boot application environment. - onApplicationEvent(ApplicationPreparedEvent) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Handles the
ApplicationPreparedEventby ensuring the event is processed only once per application context. - onApplicationEvent(ApplicationReadyEvent) - Method in class io.microsphere.spring.boot.report.ConditionEvaluationReportListener
-
Handles the
ApplicationReadyEventby reporting the condition evaluation results for the application context that triggered the event. - onApplicationEvent(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.LoggingOnceApplicationPreparedEventListener
-
Logs the application-prepared event details for the given context using
SpringApplicationUtils#log. - onApplicationEvent(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.LoggingOnceMainApplicationPreparedEventListener
-
Logs the application-prepared event details for the main application context using
SpringApplicationUtils#log. - onApplicationEvent(SpringApplication, String[], ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Called when an
ApplicationPreparedEventis received for a context that has not yet been processed and is not ignored. - onBeanFactoryConfigurationFrozen(ConfigurableListableBeanFactory) - Method in class io.microsphere.spring.boot.env.config.OriginTrackedConfigurationPropertyInitializer
-
Callback invoked when the bean factory configuration is frozen.
- OnceApplicationPreparedEventListener - Class in io.microsphere.spring.boot.context
-
This abstract class provides a base implementation for application listeners that should only execute once per application context.
- OnceApplicationPreparedEventListener() - Constructor for class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Constructs a new
OnceApplicationPreparedEventListenerand initializes the set of processed context ids for the concrete listener class. - OnceMainApplicationPreparedEventListener - Class in io.microsphere.spring.boot.context
-
Once execution
ApplicationPreparedEventApplicationListenerfor MainApplicationContext. - OnceMainApplicationPreparedEventListener() - Constructor for class io.microsphere.spring.boot.context.OnceMainApplicationPreparedEventListener
- onCreate(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in interface io.microsphere.spring.boot.context.properties.bind.BindListener
-
Called when binding of an element ends with an unbound result and a newly created instance is about to be returned.
- onCreate(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Delegates to the parent handler's
onCreateand then notifies all registeredBindListeners. - onFailure(ConfigurationPropertyName, Bindable<?>, BindContext, Exception) - Method in interface io.microsphere.spring.boot.context.properties.bind.BindListener
-
Called when binding fails for any reason (including failures from
BindListener.onSuccess(org.springframework.boot.context.properties.source.ConfigurationPropertyName, org.springframework.boot.context.properties.bind.Bindable<?>, org.springframework.boot.context.properties.bind.BindContext, java.lang.Object)Implementations may choose to swallow exceptions and return an alternative result. - onFailure(ConfigurationPropertyName, Bindable<?>, BindContext, Exception) - Method in class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Delegates to the parent handler's
onFailureand notifies all registeredBindListeners if the parent throws an exception. - onFinish(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in interface io.microsphere.spring.boot.context.properties.bind.BindListener
-
Called when binding finishes with either bound or unbound result.
- onFinish(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Delegates to the parent handler's
onFinishand then notifies all registeredBindListeners. - onStart(ConfigurationPropertyName, Bindable<T>, BindContext) - Method in interface io.microsphere.spring.boot.context.properties.bind.BindListener
-
Called when binding of an element starts but before any result has been determined.
- onStart(ConfigurationPropertyName, Bindable<T>, BindContext) - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Handles the start of a binding operation.
- onStart(ConfigurationPropertyName, Bindable<T>, BindContext) - Method in class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Delegates to the parent handler's
onStartand then notifies all registeredBindListeners. - onSuccess(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in interface io.microsphere.spring.boot.context.properties.bind.BindListener
-
Called when binding of an element ends with a successful result.
- onSuccess(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Handles a successful binding operation.
- onSuccess(ConfigurationPropertyName, Bindable<?>, BindContext, Object) - Method in class io.microsphere.spring.boot.context.properties.bind.ListenableBindHandlerAdapter
-
Delegates to the parent handler's
onSuccessand then notifies all registeredBindListeners. - OriginTrackedConfigurationPropertyInitializer - Class in io.microsphere.spring.boot.env.config
-
ApplicationContextInitializerclass supports origin tracked configuration property. - OriginTrackedConfigurationPropertyInitializer() - Constructor for class io.microsphere.spring.boot.env.config.OriginTrackedConfigurationPropertyInitializer
P
- postProcess(Map<String, Object>) - Method in interface io.microsphere.spring.boot.env.DefaultPropertiesPostProcessor
-
Post handle
(Properties) "defaultProperties", afterDefaultPropertiesPostProcessor.initializeResources(Set) - postProcessBeanFactory(ConfigurableListableBeanFactory) - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Post-processes the bean factory to initialize the internal map of
ConfigurationPropertiesBeanContextinstances for all@ConfigurationPropertiesbeans. - PropertyConstants - Interface in io.microsphere.spring.boot.constants
-
The Property constants for Microsphere Spring Boot
- PropertySourceLoaders - Class in io.microsphere.spring.boot.env
-
The composite class of
PropertySourceLoaderwith utilities features - PropertySourceLoaders() - Constructor for class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Constructs a new
PropertySourceLoadersusing the default class loader. - PropertySourceLoaders(ClassLoader) - Constructor for class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Constructs a new
PropertySourceLoadersusing the given class loader. - PropertySourceLoaders(ResourceLoader) - Constructor for class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Constructs a new
PropertySourceLoadersusing the given resource loader.
R
- read() - Method in class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
-
Reads and merges all Spring Boot configuration metadata from classpath resources, including both standard and additional metadata files.
- reloadAsOriginTracked(PropertySource<?>) - Method in class io.microsphere.spring.boot.env.PropertySourceLoaders
-
Reload the
PropertySourceas an instance ofPropertySourcewithOriginLookup - reportConditions(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.report.ConditionEvaluationReportListener
-
Reports the condition evaluation details for the given application context by building and logging condition report messages at info level.
- reportConditions(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.report.ConditionEvaluationSpringBootExceptionReporter
-
Reports the condition evaluation details for the given application context by building and logging condition report messages at error level.
- reportException(Throwable) - Method in class io.microsphere.spring.boot.report.ConditionEvaluationSpringBootExceptionReporter
-
Reports the exception by logging the failure and outputting condition evaluation details.
- run(String...) - Method in class io.microsphere.spring.boot.env.config.metadata.ConfigurationMetadataRepository
-
Reads the
ConfigurationMetadataand initializes the internal indexed maps for groups, properties, and hints. - running(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the application is fully running.
- running(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the application is fully running.
S
- setApplicationContext(ApplicationContext) - Method in class io.microsphere.spring.boot.context.properties.bind.EventPublishingConfigurationPropertiesBeanPropertyChangedListener
-
Sets the
ApplicationContext, which must be aConfigurableApplicationContext, for publishing property change events. - setBeanFactory(BeanFactory) - Method in class io.microsphere.spring.boot.context.properties.ListenableConfigurationPropertiesBindHandlerAdvisor
-
Sets the
BeanFactoryused to discoverBindListenerbeans. - setConversionService(ConversionService) - Method in class io.microsphere.spring.boot.context.config.BindableConfigurationBeanBinder
-
Sets the
ConversionServiceused during property binding to convert property values to the target types. - setEnvironment(Environment) - Method in class io.microsphere.spring.boot.autoconfigure.ConfigurableAutoConfigurationImportFilter
-
Sets the
Environmentand resolves the set of excluded auto-configuration class names from the configured properties. - setOrder(int) - Method in class io.microsphere.spring.boot.context.OnceApplicationPreparedEventListener
-
Sets the order value for this listener, controlling its execution priority among other
Orderedlisteners. - setOrder(int) - Method in class io.microsphere.spring.boot.env.DefaultPropertiesApplicationListener
-
Sets the order value of this listener.
- setOrder(int) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Set the order of this listener.
- setResourceLoader(ResourceLoader) - Method in class io.microsphere.spring.boot.context.properties.metadata.ConfigurationMetadataReader
-
Sets the
ResourceLoaderused to resolve configuration metadata resources. - SPRING_AUTO_CONFIGURE_EXCLUDE_PROPERTY_NAME - Static variable in interface io.microsphere.spring.boot.constants.SpringBootPropertyConstants
-
The property name to exclude the class names of Spring Boot Auto-Configuration
- SPRING_BOOT_3_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_13 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_0_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_1_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_2_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_13 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_3_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_13 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_4_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_10 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_11 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_12 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_13 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_14 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_8 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_3_5_9 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_2 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_3 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_4 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_5 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_6 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_0_7 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_1 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- SPRING_BOOT_4_1_0 - Enum constant in enum class io.microsphere.spring.boot.SpringBootVersion
- springApplication - Variable in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.
- SpringApplicationDefaultPropertiesPostProcessor - Class in io.microsphere.spring.boot.env
-
Spring ApplicationDefaultPropertiesPostProcessorto load the properties resources being located in the"classpath*:/META-INF/config/default/*.*" - SpringApplicationDefaultPropertiesPostProcessor() - Constructor for class io.microsphere.spring.boot.env.SpringApplicationDefaultPropertiesPostProcessor
- SpringApplicationRunListenerAdapter - Class in io.microsphere.spring.boot.listener
-
Deprecated, for removal: This API element is subject to removal in a future version.
- SpringApplicationRunListenerAdapter(SpringApplication, String[]) - Constructor for class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Construct a new
SpringApplicationRunListenerAdapterwith the given application and arguments. - SpringApplicationUtils - Class in io.microsphere.spring.boot.util
-
SpringApplicationUtilities class - SpringBootPropertyConstants - Interface in io.microsphere.spring.boot.constants
-
The Constants for Spring Boot Property
- SpringBootVersion - Enum Class in io.microsphere.spring.boot
-
The enumeration for the released Spring Boot versions since 3.0
- started(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs that the application context has been started.
- started(ConfigurableApplicationContext) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the application context has been refreshed and started.
- starting() - Method in class io.microsphere.spring.boot.classloading.BannedArtifactClassLoadingListener
-
Called when the application is starting.
- starting() - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs the starting phase of the application (legacy callback without bootstrap context).
- starting() - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the application is starting up (legacy callback without bootstrap context).
- starting(ConfigurableBootstrapContext) - Method in class io.microsphere.spring.boot.listener.LoggingSpringApplicationRunListener
-
Deprecated.Logs the starting phase of the application with the given bootstrap context.
- starting(ConfigurableBootstrapContext) - Method in class io.microsphere.spring.boot.listener.SpringApplicationRunListenerAdapter
-
Deprecated.Called when the application is starting up with a
ConfigurableBootstrapContext.
T
- toDashedForm(String) - Static method in class io.microsphere.spring.boot.context.properties.source.util.ConfigurationPropertyUtils
-
Return the specified Java Bean property name in dashed form.
- toString() - Method in class io.microsphere.spring.boot.context.properties.ConfigurationPropertiesBeanInfo
-
Returns a string representation including bean class, annotation, prefix, and property descriptors.
V
- value() - Element in annotation interface io.microsphere.spring.boot.condition.ConditionalOnPropertyPrefix
-
The prefix values of properties.
- valueOf(String) - Static method in enum class io.microsphere.spring.boot.SpringBootVersion
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class io.microsphere.spring.boot.SpringBootVersion
-
Returns an array containing the constants of this enum class, in the order they are declared.
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
ApplicationListenerforSpringApplicationEvent