Uses of Class
io.microsphere.spring.boot.SpringBootVersion
-
Packages that use SpringBootVersion Package Description io.microsphere.spring.boot -
-
Uses of SpringBootVersion in io.microsphere.spring.boot
Methods in io.microsphere.spring.boot that return SpringBootVersion Modifier and Type Method Description static SpringBootVersionSpringBootVersion. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static SpringBootVersion[]SpringBootVersion. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in io.microsphere.spring.boot with parameters of type SpringBootVersion Modifier and Type Method Description booleanSpringBootVersion. eq(SpringBootVersion that)booleanSpringBootVersion. equals(SpringBootVersion that)booleanSpringBootVersion. ge(SpringBootVersion that)booleanSpringBootVersion. gt(SpringBootVersion that)booleanSpringBootVersion. isGreaterOrEqual(SpringBootVersion that)booleanSpringBootVersion. isGreaterThan(SpringBootVersion that)booleanSpringBootVersion. isLessOrEqual(SpringBootVersion that)booleanSpringBootVersion. isLessThan(SpringBootVersion that)booleanSpringBootVersion. le(SpringBootVersion that)booleanSpringBootVersion. lt(SpringBootVersion that)
-